object code blow up by optimization

Christian Maeder maeder at tzi.de
Thu Jan 26 14:30:42 EST 2006


(Sorry, for so many emails)

The code bloat goes away again when I now change back to infixl!
Is this now a better patch for HughesPJ.hs?

Linking ...

real    5m18.860s
user    4m56.663s
sys     0m9.168s
maeder at turing:~/haskell/examples> ll a.out HasCASL/PrintLe.o
-rwxr-xr-x  1 maeder wimi 4808498 2006-01-26 20:23 a.out
-rw-r--r--  1 maeder wimi  140820 2006-01-26 20:21 HasCASL/PrintLe.o


Christian Maeder wrote:
> When I also swap the corresponding equations the code bloat comes back:
> 
> above_ p _ Empty = p
> above_ Empty _ q = q
> 
> beside_ p _ Empty = p
> beside_ Empty _ q = q
> 
> 
> Linking ...
> 
> real    7m10.727s
> user    6m25.456s
> sys     0m10.698s
> maeder at turing:~/haskell/examples> ll a.out HasCASL/PrintLe.o
> -rwxr-xr-x  1 maeder wimi 6213885 2006-01-26 20:11 a.out
> -rw-r--r--  1 maeder wimi 1762784 2006-01-26 20:09 HasCASL/PrintLe.o
> 
> 
> Christian Maeder wrote:
>> Sorry, I forgot to save my changes. The numbers are much better with 
>> infixr:
>>
>> Linking ...
>>
>> real    5m30.666s
>> user    4m56.950s
>> sys     0m9.262s
>> maeder at turing:~/haskell/examples> ll a.out HasCASL/PrintLe.o
>> -rwxr-xr-x  1 maeder wimi 4812378 2006-01-26 20:01 a.out
>> -rw-r--r--  1 maeder wimi  139828 2006-01-26 19:58 HasCASL/PrintLe.o
>>
> 



More information about the Glasgow-haskell-bugs mailing list